"""
    客户详情页面 用例
"""
import pytest
from PageObjects.customersDetails_page import CustomersDetailsPage as cdp


@pytest.mark.usefixtures("init")
class TestCustomersDetails:

    # 进入 客户跟进 菜单，进行评分操作
    def test_editor_mark(self, init):
        cdp(init).editor_mark()
        assert cdp(init).is_mark_success()

    # 进入合同页面，新建合同
    def test_add_customer_contract(self, init):
        cdp(init).add_customer_contract()
        assert cdp(init).is_contract_success()

    # 新建订单
    def test_add_order(self, init):
        cdp(init).add_order()
        assert cdp(init).is_order_success()
